@@ -52,7 +52,7 @@ def geocode(options, addresses):
     addresses = [tuple(x and x.lower() for x in a) for a in addresses]
     results = geocode_distinct(options, [
         (line1, city, zipcode)
-        for (line1, city, zipcode) in sorted(set(addresses))
+        for (line1, city, zipcode) in set(addresses)
         if line1 and city and zipcode and zipcode != 'xxxxx'])
     for a in addresses:
         yield results.get(a)
